@@ -1,17 +1,19 @@
 #!/usr/local/bin/perl -w
 use Tk;
-use lib './blib/lib'; use Tk::CollapsableFrame;
+use lib './blib/lib'; use CollapsableFrame;
 use Tk::widgets qw/LabEntry/;
 use strict;
 
 my $mw = MainWindow->new;
 
 my $cf = $mw->CollapsableFrame(
-    -width  => 300,
-    -height => 510,
-    -title  => "Copy Details",
+    -background => 'lightblue',
+    -height     => 110,
+    -title      => 'Copy Details',
+    -width      => 300,
 );
 $cf->pack(qw/-fill x -expand 1/);
+
 my $cf_frame = $cf->Subwidget('colf');
 
 # Populate the CollapsableFrame with detail information.
@@ -26,14 +28,17 @@ foreach my $item (
     ) {
     my $l = $item->[0] . ':';
     my $le = $cf_frame->LabEntry(
-        -label        => ' ' x (13 - length $l) . $l,
-        -labelPack    => [qw/-side left -anchor w/],
-        -labelFont    => '9x15bold',
-        -relief       => 'flat',
-        -state        => 'disabled',
-        -textvariable => $item->[1],
-        -width        => 35,
-				     );
+        -background          => 'lightgreen',
+        -highlightbackground => 'blue',
+        -label               => ' ' x (13 - length $l) . $l,
+        -labelBackground     => 'lightgreen',
+        -labelPack           => [qw/-side left -anchor w/],
+        -labelFont           => '9x15bold',
+        -relief              => 'flat',
+        -state               => 'disabled',
+        -textvariable        => $item->[1],
+        -width               => 35,
+    );
     $le->pack(qw/ -fill x -expand 1/);
 }
  
